from setuptools import setup, find_packages

setup(
    name="ire.py",
    version="0.0.0",
    description="Export tables and plots from Jupyter notebooks, along with metadata for embedding interactive tables in downstream apps.",
)
